<?php

namespace Litecms\ContentPackage\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\ContentPackage\Http\Requests\ContentPackageRequest;
use Litecms\ContentPackage\Interfaces\ContentPackageRepositoryInterface;
use Litecms\ContentPackage\Models\ContentPackage;

/**
 * Resource controller class for content_package.
 */
class ContentPackageResourceController extends BaseController
{

    /**
     * Initialize content_package resource controller.
     *
     * @param type ContentPackageRepositoryInterface $content_package
     *
     * @return null
     */
    public function __construct(ContentPackageRepositoryInterface $content_package)
    {
        parent::__construct();
        $this->repository = $content_package;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\ContentPackage\Repositories\Criteria\ContentPackageResourceCriteria::class);
    }

    /**
     * Display a list of content_package.
     *
     * @return Response
     */
    public function index(ContentPackageRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\ContentPackage\Repositories\Presenter\ContentPackagePresenter::class)
                ->$function();
        }

        $content_packages = $this->repository->paginate();

        return $this->response->title(trans('content_package::content_package.names'))
            ->view('content_package::content_package.index', true)
            ->data(compact('content_packages'))
            ->output();
    }

    /**
     * Display content_package.
     *
     * @param Request $request
     * @param Model   $content_package
     *
     * @return Response
     */
    public function show(ContentPackageRequest $request, ContentPackage $content_package)
    {

        if ($content_package->exists) {
            $view = 'content_package::content_package.show';
        } else {
            $view = 'content_package::content_package.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('content_package::content_package.name'))
            ->data(compact('content_package'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new content_package.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ContentPackageRequest $request)
    {

        $content_package = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('content_package::content_package.name')) 
            ->view('content_package::content_package.create', true) 
            ->data(compact('content_package'))
            ->output();
    }

    /**
     * Create new content_package.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ContentPackageRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $content_package                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('content_package::content_package.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('content_package/content_package/' . $content_package->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/content_package/content_package'))
                ->redirect();
        }

    }

    /**
     * Show content_package for editing.
     *
     * @param Request $request
     * @param Model   $content_package
     *
     * @return Response
     */
    public function edit(ContentPackageRequest $request, ContentPackage $content_package)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('content_package::content_package.name'))
            ->view('content_package::content_package.edit', true)
            ->data(compact('content_package'))
            ->output();
    }

    /**
     * Update the content_package.
     *
     * @param Request $request
     * @param Model   $content_package
     *
     * @return Response
     */
    public function update(ContentPackageRequest $request, ContentPackage $content_package)
    {
        try {
            $attributes = $request->all();

            $content_package->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('content_package::content_package.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('content_package/content_package/' . $content_package->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('content_package/content_package/' . $content_package->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the content_package.
     *
     * @param Model   $content_package
     *
     * @return Response
     */
    public function destroy(ContentPackageRequest $request, ContentPackage $content_package)
    {
        try {

            $content_package->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('content_package::content_package.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('content_package/content_package/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('content_package/content_package/' . $content_package->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple content_package.
     *
     * @param Model   $content_package
     *
     * @return Response
     */
    public function delete(ContentPackageRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('content_package::content_package.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('content_package/content_package'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/content_package/content_package'))
                ->redirect();
        }

    }

    /**
     * Restore deleted content_packages.
     *
     * @param Model   $content_package
     *
     * @return Response
     */
    public function restore(ContentPackageRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('content_package::content_package.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/content_package/content_package'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/content_package/content_package/'))
                ->redirect();
        }

    }

}
